import os
import re
import sys

from distutils.log import Log, DEBUG

from freddist import file_util
from freddist.command.install import install
from freddist.core import setup


PACKAGE_VERSION = '1.0.0'
PROJECT_NAME = 'fred_stats'
PACKAGE_NAME = 'fred_stats'

#SETTINGS_NAME = 'stats_cfg'


class FredStatsInstall(install):
    # ((module, package), ...)
    DEPS_PYMODULE = ('psycopg2',)
    DEPS_HELP = {'deb': {'psycopg2': 'python-psycopg2'}}

    def update_config_and_purelib_path(self, src, dest):
        'Update config path variable.'
        # filepath always with root (if is defined)
        body = open(src).read()
        body = re.sub("CONFIG_PATH\s*=\s*['\"]([^'\"]*)['\"]",
                      "CONFIG_PATH = '%s'" % os.path.join(self.getDir('SYSCONFDIR'), 'fred'), body)
        body = re.sub("PURELIB_PATH\s*=\s*['\"]([^'\"]*)['\"]",
                      "PURELIB_PATH = '%s'" % self.getDir('PURELIBDIR'), body)
        open(dest, 'w').write(body)

    def update_purelib_path(self, src, dest):
        'Updatate PURELIB_PATH'
        body = open(src).read()
        body = re.sub("PURELIB_PATH\s*=\s*['\"]([^'\"]*)['\"]",
                      "PURELIB_PATH = '%s'" % self.getDir('PURELIBDIR'), body)
        open(dest, 'w').write(body)



def main():
    setup(# Distribution meta-data
        name=PROJECT_NAME,
        description='Fred statistics add data script',
        author='Tomas Divis, CZ.NIC',
        author_email='tomas.divis@nic.cz',
        url='http://www.nic.cz/',
        version=PACKAGE_VERSION,
        license='GNU GPL',
        platforms=['posix'],
        long_description='Fred statistics script for adding new daily data to database.',

        #packages = [PACKAGE_NAME] + map(lambda s: '%s.%s'%(PACKAGE_NAME, s), [
        #    'stats'
        #]),
        packages=['fred_stats'],
        #package_dir = {PACKAGE_NAME: '.'},

        data_files=file_util.collect_data_files(os.path.dirname(__file__), [
            ('DOCDIR', 'doc'),
        ], 'STRIP-LEFT-FOLDER') + file_util.collect_data_files(os.path.dirname(__file__), [
            ('DOCDIR', 'cron.d'),
        ]) + [
            (os.path.join('SYSCONFDIR', 'fred'), ['stats_cfg.py']),
            ('BINDIR', ['stats_one_day.py']),
            (os.path.join('PURELIBDIR', PACKAGE_NAME), [
                os.path.join(PACKAGE_NAME, 'compute_sums_this_year.sql'),
                os.path.join(PACKAGE_NAME, 'compute_all_sums.sql'),
             ]
            ),
        ],

        # definitions for modification of the selected files:
        # modify-in-command: (module.function, (a list of files for modification)
        modify_files={
            'build_py': (('install.update_config_and_purelib_path', ['add_data.py', ]),),
            'install_data': (('install.update_purelib_path', ['stats_one_day.py', ]),),
        },

        cmdclass={
            'install': FredStatsInstall,
        },
    )

if __name__ == '__main__':
    log = Log(DEBUG)
    main()
